#!/bin/sh

# Build script for Rackarrack
# Author: Ejis <ejis@mailoo.org>

# Homepage: http://rakarrack.sourceforge.net/


set -e


SOFTNAME=rakarrack
VERSION=0.6.1
ZENVER=72
BUILD=1

CATEGORY=extra/xap

MARCH=i686
FLAGS="-O2 -march=$MARCH -mtune=i686"

CWD=$(pwd)

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

SOFTDIR=$CWD/$SOFTNAME-${VERSION}
PKGDIR=$CWD/$PKG

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep
LOG=$PKGDIR.log

SRCFILE=$SOFTNAME-${VERSION}.tar.bz2

HOSTURL=http://zenwalk.pinguix.com/user-accounts/ejis/$CATEGORY/$SOFTNAME/$ZENVER
SRCURL=http://downloads.sourceforge.net/project/$SOFTNAME/$SOFTNAME/$SOFTNAME-${VERSION}

SRCLINKS=(
	$SRCURL/$SRCFILE
)

DOC=(
	$SOFTDIR/ChangeLog
	$SOFTDIR/INSTALL
	$SOFTDIR/COPYING
	$SOFTDIR/README
	$SOFTDIR/NEWS
	$SOFTDIR/TODO
	$SOFTDIR/AUTHORS
)

EXTRADEPS=(
)

LESSDEPS=(
)


# Check for source files and download it if necessary

if [ ! -f $CWD/$SRCFILE ]; then
	wget -c -t 0 -T 50 -w 0 $SRCURL/$SRCFILE
fi


# Erase the previous build files

rm -rf $SOFTDIR $PKGDIR $MD5 $SRC $DEP $LOG
mkdir -p $PKG


# Build

tar -xvf $CWD/$SRCFILE

cd $SOFTDIR

export CFLAGS=$FLAGS
export CXXFLAGS=$FLAGS

./configure \
	--prefix=/usr \
	--localstatedir=/var \
	--sysconfdir=/etc \
	--mandir=/usr/man \
	--enable-sse

sed -i "s:i486:i686:g" Makefile
sed -i "s:i486:i686:g" src/Makefile

make -j2
make DESTDIR=$PKGDIR install


# Packaging

cd $PKGDIR

mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION
mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION
mkdir -p $PKGDIR/usr/share/icons/hicolor/48x48/apps

convert $PKGDIR/usr/share/pixmaps/icono_rakarrack_64x64.png \
	-size 48x48 \
	$PKGDIR/usr/share/icons/hicolor/48x48/apps/rakarrack.png
rm -rvf $PKGDIR/usr/share/pixmaps

sed -i "s:icono_rakarrack_128x128:rakarrack:g" \
	$PKGDIR/usr/share/applications/rakarrack.desktop


	   #|-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc <<EOF
$SOFTNAME: $SOFTNAME - Guitar Effects
$SOFTNAME:
$SOFTNAME: Rakarrack is a guitar effects processor for GNU / Linux
$SOFTNAME: simple and easy to use but it contains features that make it
$SOFTNAME: unique in this field of applications. It contains 17 effects:
$SOFTNAME: Linear Equalizer, Parametric Equalizer, Compressor, Distorsion,
$SOFTNAME: Overdrive, Echo, Chorus, Phaser, Flanger Reverb, WahWah, Alienwah,
$SOFTNAME: Harmonizer, NoiseGate, Musical Delay, Cabinet, AutoPan/Extra Stereo.
$SOFTNAME: It integrates a tuner and a MIDI converter.  It can also be handled
$SOFTNAME: by an external MIDI controller.
$SOFTNAME:
EOF


# Redundent

if [ -d $PKGDIR/usr/share/doc ]; then
	mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
	rm -rvf $PKGDIR/usr/share/doc
fi

if [ -d $PKGDIR/etc ]; then
	if [ $DOTNEW == 1 ]; then
		dotnewfiles=$(find $PKGDIR/etc -type f -print -exec \
			mv {} {}.new \;)
		cat << EOF > $PKGDIR/install/doinst.sh
dotnewfiles=(${dotnewfiles[@]})

for file in \${dotnewfiles[@]}; do
	if [ ! -f \$file ]; then
		mv \$file.new \$file
	fi
done
EOF
		sed -i "s:$PKGDIR/::g" $PKGDIR/install/doinst.sh
	fi
fi

find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true

if [ -d $PKGDIR/usr/man ]; then
	
	( cd $PKGDIR/usr/man
		find . -type f -exec gzip -9 {} \;
		for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
	)
	
fi

if [ -d $PKGDIR/usr/info ]; then
	
	rm -f $PKGDIR/usr/info/dir
	gzip -9 $PKGDIR/usr/info/*.info*
	
fi

find . -name perllocal.pod \
	-o -name ".packlist" \
	-o -name "*.bs" \
	| xargs rm -f


cp -v $CWD/build-$SOFTNAME.sh \
	$PKGDIR/usr/src/$SOFTNAME-$VERSION/

cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


# fix permissions and ownership
fakeroot chown -R root:root .
find . -perm 777 -exec fakeroot chmod 755 {} \;
find . -perm 775 -exec fakeroot chmod 755 {} \;
find . -perm 666 -exec fakeroot chmod 644 {} \;
find . -perm 664 -exec fakeroot chmod 644 {} \;
find . -perm 600 -exec fakeroot chmod 644 {} \;
find . -perm 444 -exec fakeroot chmod 644 {} \;
find . -perm 400 -exec fakeroot chmod 644 {} \;
find . -perm 440 -exec fakeroot chmod 644 {} \;
find . -perm 511 -exec fakeroot chmod 755 {} \;
find . -perm 711 -exec fakeroot chmod 755 {} \;
find . -perm 555 -exec fakeroot chmod 755 {} \;


fakeroot /sbin/makepkg -l y -c n $PKGFILE


cd $CWD

echo 'Creating .md5 file'
md5sum $PKG.txz > $MD5

echo 'Creating .src file'
echo "$HOSTURL/build-$SOFTNAME.sh" > $SRC
for link in ${SRCLINKS[@]}; do
	echo $link >> $SRC
done

echo 'Checking for dependencies'
deps=$(depfinder $PKGFILE)

for dep in ${EXTRADEPS[@]}; do
	deps="$deps,$dep"
done

for dep in ${LESSDEPS[@]}; do
	deps=${deps/$dep/}
done

order=$(echo ${deps//,/ } | sort -d)
echo ${order// /,} > $DEP

echo "Removing build directories"
rm -rf $SOFTDIR $PKG
